@@ -59,6 +59,9 @@ class SearchModeBase(object):
 
     @classmethod
     def _match(cls, dirname, filename, candidate):
+        # Circular dependency.
+        from .Common import getStartDir
+
         parts = [dirname, filename]
 
         while None in parts:
@@ -70,18 +73,17 @@ class SearchModeBase(object):
         candidates = (
             dirname,
             filename,
-            filename.replace(".py", ""),
-            filename.split(".")[0],
+            filename.rsplit(".", 1)[0],
+            filename.rsplit(".", 1)[0].replace("Test", ""),
             path,
-            path.replace(".py", ""),
+            path.rsplit(".", 1)[0],
+            path.rsplit(".", 1)[0].replace("Test", ""),
         )
 
-        candidate2 = os.path.relpath(
-            candidate, os.path.dirname(sys.modules["__main__"].__file__)
+        return candidate.rstrip("/") in candidates or areSamePaths(
+            os.path.join(getStartDir(), candidate), filename
         )
 
-        return candidate.rstrip("/") in candidates or candidate2 in candidates
-
     def exit(self, message):
         # Virtual method, pylint: disable=no-self-use
         sys.exit(message)
@@ -106,6 +108,9 @@ class SearchModeByPattern(SearchModeBase):
         self.start_at = start_at
 
     def consider(self, dirname, filename):
+        if self.start_at is None:
+            self.active = True
+
         if self.active:
             return True
 
@@ -169,7 +174,7 @@ class SearchModeResume(SearchModeBase):
             sys.exit("Error, became never active, restarting next time.")
 
 
-class SearchModeCoverage(SearchModeBase):
+class SearchModeCoverage(SearchModeByPattern):
     def getExtraFlags(self, dirname, filename):
         return ["coverage"]
 
@@ -195,18 +200,3 @@ class SearchModeOnly(SearchModeByPattern):
                 self.done = True
 
             return active
-
-
-class SearchModeAll(SearchModeBase):
-    def __init__(self):
-        SearchModeBase.__init__(self)
-        self.total_errors = 0
-
-    def updateTotalErrors(self):
-        self.total_errors += 1
-
-    def onErrorDetected(self, message):
-        self.updateTotalErrors()
-
-    def finish(self):
-        self.exit("Total " + str(self.total_errors) + " error(s) found.")
